summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--tests/local-connection.c2
-rw-r--r--ytstenut/Makefile.am17
-rw-r--r--ytstenut/video-profile/yts-vp-query.c8
-rw-r--r--ytstenut/video-profile/yts-vp-query.h8
-rw-r--r--ytstenut/yts-client.c14
-rw-r--r--ytstenut/yts-error.h2
-rw-r--r--ytstenut/yts-version.h.in46
-rw-r--r--ytstenut/ytstenut.sym122
8 files changed, 176 insertions, 43 deletions
diff --git a/tests/local-connection.c b/tests/local-connection.c
index 48336b9..d02c47b 100644
--- a/tests/local-connection.c
+++ b/tests/local-connection.c
@@ -107,7 +107,7 @@ contact_status_cb (YtsContact *item, GParamSpec *spec, gpointer data)
}
/*
- * Demonstrates how to send nScreen command to an item in the roster.
+ * Demonstrates how to send Ytstenut command to an item in the roster.
*/
static gboolean
timeout_cb (gpointer data)
diff --git a/ytstenut/Makefile.am b/ytstenut/Makefile.am
index 53f42c5..60d4861 100644
--- a/ytstenut/Makefile.am
+++ b/ytstenut/Makefile.am
@@ -113,6 +113,10 @@ libytstenut_@YTS_API_VERSION@_la_SOURCES = $(source_h) \
$(private_h) \
$(source_c)
+libytstenut_@YTS_API_VERSION@_la_DEPENDENCIES = \
+ ytstenut.sym \
+ $(NULL)
+
STAMPS = stamp-marshal.h stamp-yts-enum-types.h
ENUMS = yts-enum-types.h \
@@ -157,9 +161,15 @@ yts-marshal.c: yts-marshal.h Makefile
&& cp xgen-cmc yts-marshal.c \
&& rm -f xgen-cmc
-libytstenut_@YTS_API_VERSION@_la_LDFLAGS = $(YTS_LT_LDFLAGS) \
- -no-undefined
-libytstenut_@YTS_API_VERSION@_la_LIBADD = $(YTS_LIBS)
+libytstenut_@YTS_API_VERSION@_la_LDFLAGS = \
+ $(YTS_LT_LDFLAGS) \
+ -export-symbols $(srcdir)/ytstenut.sym \
+ -no-undefined \
+ $(NULL)
+
+libytstenut_@YTS_API_VERSION@_la_LIBADD = \
+ $(YTS_LIBS) \
+ $(NULL)
lib_LTLIBRARIES = libytstenut-@YTS_API_VERSION@.la
@@ -224,6 +234,7 @@ EXTRA_DIST = marshal.list \
yts-enum-types.c.in \
yts-version.h.in \
ytstenut-1.pc.in \
+ ytstenut.sym \
$(NULL)
DISTCLEANFILES= yts-version.h \
diff --git a/ytstenut/video-profile/yts-vp-query.c b/ytstenut/video-profile/yts-vp-query.c
index 9a3e1eb..c4c45ce 100644
--- a/ytstenut/video-profile/yts-vp-query.c
+++ b/ytstenut/video-profile/yts-vp-query.c
@@ -76,7 +76,7 @@ yts_vp_query_default_init (YtsVPQueryInterface *interface)
}
unsigned
-yts_vp_get_max_results (YtsVPQuery *self)
+yts_vp_query_get_max_results (YtsVPQuery *self)
{
unsigned max_results;
@@ -88,7 +88,7 @@ yts_vp_get_max_results (YtsVPQuery *self)
}
unsigned
-yts_vp_get_progress (YtsVPQuery *self)
+yts_vp_query_get_progress (YtsVPQuery *self)
{
unsigned progress;
@@ -100,7 +100,7 @@ yts_vp_get_progress (YtsVPQuery *self)
}
GList *
-yts_vp_get_results (YtsVPQuery *self)
+yts_vp_query_get_results (YtsVPQuery *self)
{
GList *results;
@@ -112,7 +112,7 @@ yts_vp_get_results (YtsVPQuery *self)
}
YtsVPQueryResultOrder
-yts_vp_get_result_order (YtsVPQuery *self)
+yts_vp_query_get_result_order (YtsVPQuery *self)
{
YtsVPQueryResultOrder result_order;
diff --git a/ytstenut/video-profile/yts-vp-query.h b/ytstenut/video-profile/yts-vp-query.h
index 83cfa4b..0c266d3 100644
--- a/ytstenut/video-profile/yts-vp-query.h
+++ b/ytstenut/video-profile/yts-vp-query.h
@@ -59,16 +59,16 @@ GType
yts_vp_query_get_type (void) G_GNUC_CONST;
unsigned
-yts_vp_get_max_results (YtsVPQuery *self);
+yts_vp_query_get_max_results (YtsVPQuery *self);
unsigned
-yts_vp_get_progress (YtsVPQuery *self);
+yts_vp_query_get_progress (YtsVPQuery *self);
GList *
-yts_vp_get_results (YtsVPQuery *self);
+yts_vp_query_get_results (YtsVPQuery *self);
YtsVPQueryResultOrder
-yts_vp_get_result_order (YtsVPQuery *self);
+yts_vp_query_get_result_order (YtsVPQuery *self);
G_END_DECLS
diff --git a/ytstenut/yts-error.h b/ytstenut/yts-error.h
index 965d783..2264ddd 100644
--- a/ytstenut/yts-error.h
+++ b/ytstenut/yts-error.h
@@ -43,7 +43,7 @@ G_BEGIN_DECLS
* @YTS_ERROR_CUSTOM_START: custom error codes can start at this value
* @YTS_ERROR_CUSTOM_END: custom error code must not exceed this value
*
- * YtsError represents common errors for nScreen operation; YtsError combines
+ * YtsError represents common errors for Ytstenut operation; YtsError combines
* an error code defined by the above enumeration and an atom value that
* uniquely identifies the operation associated with the value. Use
* yts_error_get_code() and yts_error_get_atom() to retrieve these components.
diff --git a/ytstenut/yts-version.h.in b/ytstenut/yts-version.h.in
index eae2486..aaa55da 100644
--- a/ytstenut/yts-version.h.in
+++ b/ytstenut/yts-version.h.in
@@ -1,26 +1,25 @@
-/* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
-
/*
- * Copyright (c) 2011 Intel Corp.
- *
- * Author: Tomas Frydrych <tf@linux.intel.com>
+ * Copyright © 2011 Intel Corp.
*
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library. If not, see
+ * <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Tomas Frydrych <tf@linux.intel.com>
*/
-#ifndef _YTS_VERSION_H
-#define _YTS_VERSION_H
+#ifndef YTS_VERSION_H
+#define YTS_VERSION_H
#include <glib.h>
@@ -29,35 +28,35 @@ G_BEGIN_DECLS
/**
* YTS_MAJOR_VERSION:
*
- * The major version of the Nscreen library (1, if %YTS_VERSION is 1.2.3)
+ * The major version of the Ytstenut library (1, if %YTS_VERSION is 1.2.3)
*/
#define YTS_MAJOR_VERSION (@YTS_MAJOR_VERSION@)
/**
* YTS_MINOR_VERSION:
*
- * The minor version of the Nscreen library (2, if %YTS_VERSION is 1.2.3)
+ * The minor version of the Ytstenut library (2, if %YTS_VERSION is 1.2.3)
*/
#define YTS_MINOR_VERSION (@YTS_MINOR_VERSION@)
/**
* YTS_MICRO_VERSION:
*
- * The micro version of the Nscreen library (3, if %YTS_VERSION is 1.2.3)
+ * The micro version of the Ytstenut library (3, if %YTS_VERSION is 1.2.3)
*/
#define YTS_MICRO_VERSION (@YTS_MICRO_VERSION@)
/**
* YTS_VERSION:
- *
- * The full version of the Nscreen library, like 1.2.3
+ *s
+ * The full version of the Ytstenut library, like 1.2.3
*/
#define YTS_VERSION @YTS_VERSION@
/**
* YTS_VERSION_S:
*
- * The full version of the Nscreen library, in string form (suited for
+ * The full version of the Ytstenut library, in string form (suited for
* string concatenation)
*/
#define YTS_VERSION_S "@YTS_VERSION@"
@@ -65,7 +64,7 @@ G_BEGIN_DECLS
/**
* YTS_VERSION_HEX:
*
- * Numerically encoded version of the Nscreen library, like 0x010203
+ * Numerically encoded version of the Ytstenut library, like 0x010203
*/
#define YTS_VERSION_HEX ((YTS_MAJOR_VERSION << 24) | \
(YTS_MINOR_VERSION << 16) | \
@@ -77,7 +76,7 @@ G_BEGIN_DECLS
* @minor: minor version, like 2 in 1.2.3
* @micro: micro version, like 3 in 1.2.3
*
- * Evaluates to %TRUE if the version of the Nscreen library is greater
+ * Evaluates to %TRUE if the version of the Ytstenut library is greater
* than @major, @minor and @micro
*/
#define YTS_CHECK_VERSION(major,minor,micro) \
@@ -87,4 +86,5 @@ G_BEGIN_DECLS
G_END_DECLS
-#endif /* _YTS_VERSION_H */
+#endif /* YTS_VERSION_H */
+
diff --git a/ytstenut/ytstenut.sym b/ytstenut/ytstenut.sym
new file mode 100644
index 0000000..f987949
--- /dev/null
+++ b/ytstenut/ytstenut.sym
@@ -0,0 +1,122 @@
+yts_capability_get_type
+yts_capability_get_fqc_ids
+yts_capability_status_get_type
+yts_capability_status_new
+yts_client_connect
+yts_client_disconnect
+yts_client_emit_error
+yts_client_get_incoming_file_directory
+yts_client_get_jid
+yts_client_get_roster
+yts_client_get_type
+yts_client_get_uid
+yts_client_new
+yts_client_register_service
+yts_client_set_capabilities
+yts_client_set_incoming_file_directory
+yts_client_set_status
+yts_client_set_status_by_capability
+yts_contact_cancel_file
+yts_contact_get_client
+yts_contact_get_icon
+yts_contact_get_jid
+yts_contact_get_name
+yts_contact_get_tp_contact
+yts_contact_get_type
+yts_contact_has_capability
+yts_contact_send_file
+yts_debug_flags_get_type
+yts_error_get_atom
+yts_error_get_code
+yts_error_get_type
+yts_error_make
+yts_error_message_get_type
+yts_error_message_new
+yts_error_new
+yts_error_new_atom
+yts_event_message_get_type
+yts_event_message_new
+yts_get_option_group
+yts_init
+yts_invocation_message_get_type
+yts_invocation_message_new
+yts_message_get_type
+yts_message_new
+yts_metadata_add_attribute
+yts_metadata_get_attribute
+yts_metadata_get_root_node
+yts_metadata_get_type
+yts_metadata_is_equal
+yts_metadata_service_get_type
+yts_metadata_service_send_metadata
+yts_metadata_to_string
+yts_presence_get_type
+yts_protocol_get_type
+yts_proxy_create_invocation_id
+yts_proxy_get_fqc_id
+yts_proxy_get_type
+yts_proxy_invoke
+yts_proxy_service_create_proxy
+yts_proxy_service_get_type
+yts_proxy_service_new
+yts_response_message_get_type
+yts_response_message_new
+yts_roster_find_contact_by_capability
+yts_roster_find_contact_by_jid
+yts_roster_get_client
+yts_roster_get_contacts
+yts_roster_get_type
+yts_service_adapter_collect_properties
+yts_service_adapter_get_fqc_id
+yts_service_adapter_get_service
+yts_service_adapter_get_type
+yts_service_adapter_invoke
+yts_service_adapter_send_error
+yts_service_adapter_send_event
+yts_service_adapter_send_response
+yts_service_get_caps
+yts_service_get_contact
+yts_service_get_jid
+yts_service_get_names
+yts_service_get_service_type
+yts_service_get_status_xml
+yts_service_get_type
+yts_service_get_uid
+yts_service_has_capability
+yts_status_get_type
+yts_status_new
+yts_vp_content_get_type
+yts_vp_query_get_max_results
+yts_vp_query_get_progress
+yts_vp_query_get_result_order
+yts_vp_query_get_results
+yts_vp_query_get_type
+yts_vp_query_result_order_get_type
+yts_vp_playable_get_type
+yts_vp_player_get_playable
+yts_vp_player_get_playable_uri
+yts_vp_player_get_playing
+yts_vp_player_get_type
+yts_vp_player_get_volume
+yts_vp_player_next
+yts_vp_player_next_return
+yts_vp_player_pause
+yts_vp_player_play
+yts_vp_player_prev
+yts_vp_player_prev_return
+yts_vp_player_set_playable
+yts_vp_player_set_playable_uri
+yts_vp_player_set_playing
+yts_vp_player_set_volume
+yts_vp_transcript_get_available_locales
+yts_vp_transcript_get_current_text
+yts_vp_transcript_get_locale
+yts_vp_transcript_get_type
+yts_vp_transcript_set_locale
+yts_vp_transfer_download
+yts_vp_transfer_get_type
+yts_vp_transfer_upload
+yts_vp_transmission_get_local_uri
+yts_vp_transmission_get_progress
+yts_vp_transmission_get_remote_uri
+yts_vp_transmission_get_type
diff --git a/ytstenut/yts-client.c b/ytstenut/yts-client.c
index 80642f9..0308d79 100644
--- a/ytstenut/yts-client.c
+++ b/ytstenut/yts-client.c
@@ -949,7 +949,7 @@ yts_client_class_init (YtsClientClass *klass)
* YtsClient::authenticated
* @client: object which emitted the signal,
*
* The authenticated signal is emited when connection to the nScreen server
* is successfully established.
*
* Since: 0.1
@@ -985,7 +985,7 @@ yts_client_class_init (YtsClientClass *klass)
* YtsClient::disconnected
* @client: object which emitted the signal,
*
* The disconnected signal is emited when connection to the nScreen server
* is successfully established.
*
* Since: 0.1
@@ -1025,7 +1025,7 @@ yts_client_class_init (YtsClientClass *klass)
* @error: #YtsError
*
* The error signal is emitted to indicate an error (or eventual success)
* during the handling of an operation for which the nScreen API initially
* returned %YTS_ERROR_PENDING. The original operation can be determined
* using the atom part of the #YtsError parameter.
*
@@ -2339,7 +2339,7 @@ yts_client_setup_account_connection (YtsClient *client)
if (error)
{
- g_critical (G_STRLOC ": %s: %s; no nScreen functionality will be "
+ g_critical (G_STRLOC ": %s: %s; no Ytstenut functionality will be "
"available", __FUNCTION__, error->message);
g_clear_error (&error);
return;
@@ -2354,7 +2354,7 @@ yts_client_setup_account_connection (YtsClient *client)
if (error)
{
- g_critical (G_STRLOC ": %s: %s; no nScreen functionality will be "
+ g_critical (G_STRLOC ": %s: %s; no Ytstenut functionality will be "
"available", __FUNCTION__, error->message);
g_clear_error (&error);
return;
@@ -2369,7 +2369,7 @@ yts_client_setup_account_connection (YtsClient *client)
if (error)
{
- g_critical (G_STRLOC ": %s: %s; no nScreen functionality will be "
+ g_critical (G_STRLOC ": %s: %s; no Ytstenut functionality will be "
"available", __FUNCTION__, error->message);
g_clear_error (&error);
return;
@@ -2666,7 +2666,7 @@ yts_client_emit_error (YtsClient *client, YtsError error)
* @directory: path to a directory or %NULL.
*
* Sets the directory where incoming files will be stored; if the provided path
* is %NULL, the directory will be reset to the default (~/.nscreen/). This
* function does not do any checks regarding validity of the path provided,
* though an attempt to create the directory before it is used, with permissions
* of 0700.
@@ -949,7 +949,7 @@ yts_client_class_init (YtsClientClass *klass)
* @client: object which emitted the signal,
*
- * The authenticated signal is emited when connection to the nScreen server
+ * The authenticated signal is emited when connection to the Ytstenut server
* is successfully established.
*
@@ -985,7 +985,7 @@ yts_client_class_init (YtsClientClass *klass)
* @client: object which emitted the signal,
*
- * The disconnected signal is emited when connection to the nScreen server
+ * The disconnected signal is emited when connection to the Ytstenut server
* is successfully established.
*
@@ -1025,7 +1025,7 @@ yts_client_class_init (YtsClientClass *klass)
*
* The error signal is emitted to indicate an error (or eventual success)
- * during the handling of an operation for which the nScreen API initially
+ * during the handling of an operation for which the Ytstenut API initially
* returned %YTS_ERROR_PENDING. The original operation can be determined
* using the atom part of the #YtsError parameter.
@@ -2666,7 +2666,7 @@ yts_client_emit_error (YtsClient *client, YtsError error)
*
* Sets the directory where incoming files will be stored; if the provided path
- * is %NULL, the directory will be reset to the default (~/.nscreen/). This
+ * is %NULL, the directory will be reset to the default (~/.Ytstenut/). This
* function does not do any checks regarding validity of the path provided,
* though an attempt to create the directory before it is used, with permissions